Environment variables - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Environment variables

Betty reads the following environment variables:

`BETTY_CACHE_DIRECTORY`

  The path to a directory for Betty to use as its application cache. Defaults to `.betty` in the current user’s home directory. This is primarily used for testing an externally running Betty application.